@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt_extra.c,v 1.19 2002/01/24 10:47:12 nmav Exp $ */
+/* $Id: mcrypt_extra.c,v 1.20 2002/01/31 01:13:58 nmav Exp $ */
 
 #include <libdefs.h>
 #include <bzero.h>
@@ -91,7 +91,7 @@ WIN32DLL_DEFINE char **mcrypt_list_algorithms(char *libdir, int *size)
 				if (filename==NULL) {
 					goto freeall;
 				}
-				filename[*size] = (char*) strdup( mps[i].name);
+				filename[*size] = strdup( mps[i].name);
 				if (filename[*size]==NULL) goto freeall;
 				(*size)++;
 			}
@@ -196,7 +196,7 @@ WIN32DLL_DEFINE char **mcrypt_list_modes(char *libdir, int *size)
 				if (filename==NULL) {
 					goto freeall;
 				}
-				filename[*size] = (char*) strdup( mps[i].name);
+				filename[*size] = strdup( mps[i].name);
 				if (filename[*size]==NULL) goto freeall;
 				(*size)++;
 			}
