@@ -1,3 +1,7 @@
+#ifndef LIBDEFS_H
+#define LIBDEFS_H
+#include <libdefs.h>
+#endif
 
 /* Local Defines */
 
@@ -7,8 +11,20 @@
 #endif
 
 typedef struct {
-	lt_dlhandle algorithm_handle;
-	lt_dlhandle mode_handle;
+	char* name;
+	lt_ptr address;
+} mcrypt_preloaded;
+
+typedef struct {
+		lt_dlhandle handle;
+		char name[64];
+} mcrypt_dlhandle;
+
+#define MCRYPT_INTERNAL_HANDLER (void*)-1
+
+typedef struct {
+	mcrypt_dlhandle algorithm_handle;
+	mcrypt_dlhandle mode_handle;
 
 	/* Holds the algorithm's internal key */
 	byte *akey;
@@ -58,7 +74,6 @@ int mcrypt_enc_is_block_algorithm_mode(MCRYPT td);
 int mcrypt_module_algorithm_version(char *algorithm, char *a_directory);
 int mcrypt_module_mode_version(char *mode, char *m_directory);
 int mcrypt_get_size(MCRYPT td);
-int *mcrypt_enc_get_supported_key_sizes(MCRYPT td, int *len);
 
 
 #define MCRYPT_UNKNOWN_ERROR -1
@@ -68,3 +83,7 @@ int *mcrypt_enc_get_supported_key_sizes(MCRYPT td, int *len);
 #define MCRYPT_UNKNOWN_MODE -5
 #define MCRYPT_UNKNOWN_ALGORITHM -6
 
+lt_ptr mcrypt_dlsym( mcrypt_dlhandle, char* str);
+void mcrypt_dlclose( mcrypt_dlhandle mod);
+lt_ptr _mcrypt_search_symlist_lib(const char* name);
+lt_ptr _mcrypt_search_symlist_sym(mcrypt_dlhandle handle, const char* _name);
