@@ -321,6 +321,25 @@ int mcrypt_enc_set_state(MCRYPT td, void *iv, int size)
 	return __mcrypt_set_state(td->abuf, iv, size);
 }
 
+WIN32DLL_DEFINE
+int mcrypt_enc_get_state(MCRYPT td, void *iv, int *size)
+{
+	int (*__mcrypt_get_state) (void *, void *, int*);
+	const char *error;
+
+	__mcrypt_get_state = mcrypt_dlsym(td->mode_handle, "_mcrypt_get_state");
+	if (__mcrypt_get_state==NULL) {
+		error = lt_dlerror();
+		if (error!=NULL) {
+			fputs(error, stderr);
+			fputs("\n", stderr);
+		}
+		return MCRYPT_UNKNOWN_ERROR;
+	}
+	return __mcrypt_get_state(td->abuf, iv, size);
+}
+
+
 WIN32DLL_DEFINE
 int mcrypt_enc_get_block_size(MCRYPT td)
 {
