@@ -22,7 +22,6 @@
 #include <stdlib.h>
 #include "arcfour.h"
 
-#ifdef USE_LTDL
 #define _mcrypt_set_key arcfour_LTX__mcrypt_set_key
 #define _mcrypt_encrypt arcfour_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt arcfour_LTX__mcrypt_decrypt
@@ -35,11 +34,12 @@
 #define _mcrypt_get_algorithms_name arcfour_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test arcfour_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version arcfour_LTX__mcrypt_algorithm_version
-#endif
 
 #define swap_byte(x,y) tmp = (x); (x) = (y); (y) = tmp
 
-#define USE_IV			/* mcrypt extension */
+/* #define USE_IV */
+/* IV was an mcrypt extension */
+
 void _mcrypt_encrypt(arcfour_key * key, byte * buffer_ptr, int buffer_len);
 
 /* key is the state that should be allocated by the caller */
