@@ -72,18 +72,18 @@ typedef struct {
 
 /****** function prototypes ******/
 
-void pan_pull(word32 * restrict In,	/* input array                    */
+static void pan_pull(word32 * restrict In,	/* input array                    */
 	      word32 * restrict Out,	/* output array                   */
 	      word32 pan_blocks,	/* number of blocks to be Pulled  */
 	      PAN_BUFFER * restrict buffer,	/* LFSR buffer                    */
 	      PAN_STATE * restrict state);	/* 17-word finite-state machine   */
 
-void pan_push(word32 * restrict In,	/* input array                    */
+static void pan_push(word32 * restrict In,	/* input array                    */
 	      word32 pan_blocks,	/* number of blocks to be Pushed  */
 	      PAN_BUFFER * restrict buffer,	/* LFSR buffer                    */
 	      PAN_STATE * restrict state);	/* 17-word finite-state machine   */
 
-void pan_reset(PAN_BUFFER * buffer, PAN_STATE * state);
+static void pan_reset(PAN_BUFFER * buffer, PAN_STATE * state);
 
 #ifndef USE_MODULES
 void _mcrypt_panama_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
