@@ -21,7 +21,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: safer64.c,v 1.9 2001/09/09 09:52:55 nmav Exp $ */
+/* $Id: safer64.c,v 1.10 2002/03/09 20:29:04 nmav Exp $ */
 
 /******************* External Headers *****************************************/
 
@@ -32,7 +32,6 @@
 #include "safer.h"
 
 
-#ifdef USE_LTDL
 #define _mcrypt_set_key safer_sk64_LTX__mcrypt_set_key
 #define _mcrypt_encrypt safer_sk64_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt safer_sk64_LTX__mcrypt_decrypt
@@ -44,7 +43,6 @@
 #define _mcrypt_get_algorithms_name safer_sk64_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test safer_sk64_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version safer_sk64_LTX__mcrypt_algorithm_version
-#endif
 
 /******************* Constants ************************************************/
 #define TAB_LEN      256
