@@ -9,7 +9,7 @@
 /* Copyright in this implementation is held by Dr B R Gladman but I     */
 /* hereby give permission for its free direct or derivative use subject */
 /* to acknowledgment of its origin and compliance with any conditions   */
-/* that the originators of t he algorithm place on its exploitation.     */
+/* that the originators of t he algorithm place on its exploitation.    */
 /*                                                                      */
 /* My thanks to Doug Whiting and Niels Ferguson for comments that led   */
 /* to improvements in this implementation.                              */
@@ -20,7 +20,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: twofish.c,v 1.10 2001/09/09 09:52:55 nmav Exp $ */
+/* $Id: twofish.c,v 1.13 2002/03/09 20:29:04 nmav Exp $ */
 
 /* Timing data for Twofish (twofish.c)
 
@@ -49,7 +49,6 @@
 #include <mcrypt_modules.h>
 #include "twofish.h"
 
-#ifdef USE_LTDL
 #define _mcrypt_set_key twofish_LTX__mcrypt_set_key
 #define _mcrypt_encrypt twofish_LTX__mcrypt_encrypt
 #define _mcrypt_decrypt twofish_LTX__mcrypt_decrypt
@@ -61,7 +60,6 @@
 #define _mcrypt_get_algorithms_name twofish_LTX__mcrypt_get_algorithms_name
 #define _mcrypt_self_test twofish_LTX__mcrypt_self_test
 #define _mcrypt_algorithm_version twofish_LTX__mcrypt_algorithm_version
-#endif
 
 /* word32  k_len;
  * word32  l_key[40];
@@ -479,16 +477,26 @@ WIN32DLL_DEFINE
 	return 0;
 }
 
+/* This macro was moved to an inline function, because it
+ * was breaking some compilers.
+ */
+inline 
+static void f_rnd(int i, word32* blk, TWI* pkey, word32 t0, word32 t1)
+{
+    t1 = g1_fun(blk[1]); 
+    t0 = g0_fun(blk[0]);
+    
+    blk[2] = rotr32(blk[2] ^ (t0 + t1 + pkey->l_key[4 * (i) + 8]), 1);
+
+    blk[3] = rotl32(blk[3], 1) ^ (t0 + 2 * t1 + pkey->l_key[4 * (i) + 9]);
+    t1 = g1_fun(blk[3]); 
+    t0 = g0_fun(blk[2]);
+    
+    blk[0] = rotr32(blk[0] ^ (t0 + t1 + pkey->l_key[4 * (i) + 10]), 1);
+    blk[1] = rotl32(blk[1], 1) ^ (t0 + 2 * t1 + pkey->l_key[4 * (i) + 11]);
+}
+
 /* encrypt a block of text  */
-
-#define f_rnd(i)                                                    \
-    t1 = g1_fun(blk[1]); t0 = g0_fun(blk[0]);                       \
-    blk[2] = rotr32(blk[2] ^ (t0 + t1 + pkey->l_key[4 * (i) + 8]), 1);      \
-    blk[3] = rotl32(blk[3], 1) ^ (t0 + 2 * t1 + pkey->l_key[4 * (i) + 9]);  \
-    t1 = g1_fun(blk[3]); t0 = g0_fun(blk[2]);                       \
-    blk[0] = rotr32(blk[0] ^ (t0 + t1 + pkey->l_key[4 * (i) + 10]), 1);     \
-    blk[1] = rotl32(blk[1], 1) ^ (t0 + 2 * t1 + pkey->l_key[4 * (i) + 11])
-
 WIN32DLL_DEFINE void _mcrypt_encrypt(TWI * pkey, word32 * in_blk)
 {
 	word32 t0, t1, blk[4];
@@ -504,14 +512,14 @@ WIN32DLL_DEFINE void _mcrypt_encrypt(TWI * pkey, word32 * in_blk)
 	blk[3] = in_blk[3] ^ pkey->l_key[3];
 #endif
 
-	f_rnd(0);
-	f_rnd(1);
-	f_rnd(2);
-	f_rnd(3);
-	f_rnd(4);
-	f_rnd(5);
-	f_rnd(6);
-	f_rnd(7);
+	f_rnd(0, blk, pkey, t0, t1);
+	f_rnd(1, blk, pkey, t0, t1);
+	f_rnd(2, blk, pkey, t0, t1);
+	f_rnd(3, blk, pkey, t0, t1);
+	f_rnd(4, blk, pkey, t0, t1);
+	f_rnd(5, blk, pkey, t0, t1);
+	f_rnd(6, blk, pkey, t0, t1);
+	f_rnd(7, blk, pkey, t0, t1);
 
 #ifdef WORDS_BIGENDIAN
 	in_blk[0] = byteswap32(blk[2] ^ pkey->l_key[4]);
@@ -627,9 +635,11 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 		plaintext[j] = j % 256;
 	}
 	key = malloc(_mcrypt_get_size());
-	if (key == NULL)
+	if (key == NULL) {
+		free( keyword);
 		return -1;
-
+	}
+	
 	memcpy(ciphertext, plaintext, blocksize);
 
 	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
