@@ -22,7 +22,8 @@
 
 /* EBC MODE */
 
-#ifdef USE_LTDL
+#define _mcrypt_set_state ecb_LTX__mcrypt_set_state
+#define _mcrypt_get_state ecb_LTX__mcrypt_get_state
 #define _init_mcrypt ecb_LTX__init_mcrypt
 #define _end_mcrypt ecb_LTX__end_mcrypt
 #define _mcrypt ecb_LTX__mcrypt
@@ -33,7 +34,6 @@
 #define _mcrypt_get_modes_name ecb_LTX__mcrypt_get_modes_name
 #define _mcrypt_mode_get_size ecb_LTX__mcrypt_mode_get_size
 #define _mcrypt_mode_version ecb_LTX__mcrypt_mode_version
-#endif
 
 int _init_mcrypt( void* ign, void *key, int lenofkey, void *IV, int size)
 {
@@ -41,6 +41,9 @@ int _init_mcrypt( void* ign, void *key, int lenofkey, void *IV, int size)
 
 }
 
+int _mcrypt_set_state( void* buf, void *IV, int size) { return -1; }
+int _mcrypt_get_state( void* buf, void *IV, int *size) { return -1; }
+
 int _end_mcrypt (void* buf) {return 0;}
 
 int _mcrypt( void* ign, void *plaintext, int len, int blocksize, void* akey, void (*func)(void*,void*), void (*func2)(void*,void*))
