@@ -1,5 +1,5 @@
 /*
- *    Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
+ *    Copyright (C) 1998,1999,2000,2002 Nikos Mavroyanopoulos
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -83,7 +83,10 @@ int main()
 						return -1;
 					}
 
-					siz = (strlen(TEXT) / mcrypt_enc_get_block_size(td))*mcrypt_enc_get_block_size(td);
+					if (mcrypt_enc_is_block_mode(td)!=0)
+						siz = (strlen(TEXT) / mcrypt_enc_get_block_size(td))*mcrypt_enc_get_block_size(td);
+					else siz = strlen(TEXT);
+
 					text = calloc( 1, siz);
 					if (text==NULL) exit(1);
 					
